warning off;
% Load JET model
load PlasmaModel

% Plasma Current Controller Design

% Open simulation scheme
PlasmaPlant_XSC

% Time constant matrix Lambda
T = eye(9);
T(1,1) = -M(end,1)/M(end,end); % assume superconductive plasma
                               % and only mutual inductance between plasma
                               % and Pi

Lambda= inv(diag([0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1 0.1]));

% Current controller
K = M(1:9,1:9)*inv(T)*Lambda;


% Model matrices
[A,B,C,D]=ssdata(sys_plant);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% JET GAPS, STRIKE POINTS and X-POINT
% LOG   ROG   ZUP   RIG   TOG3  TOG4          
% TOG5  GAP4  GAP6  GAP7  GAP17 GAP18 GAP19 GAP20         
% GAP21 GAP22 GAP23 GAP24 GAP25 GAP26 GAP27 GAP28 GAP29 GAP30         
% GAP31 RSIGB ZSOGB ZSIGB CV-RX CV-ZX
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ShapeSelector = [1:4 8:10 12:33 36:38]+10;
% Output matrix from currents to plasma shape descriptors
CC = C(ShapeSelector,2:9);

% Gap weights matrix
Q = eye(size(CC,1));
Q(2,2) = 3;   % weight on ROG
% Q(19,19) = 2;
% Q(21,21) = 2;
% Q(22,22) = 2;

% Q(6,6) = 6; % weights on TOG3
% Q(29,29)= 2.5; % weight on RSOGB

% SVD
[U,Sigma,V] = svd(Q*CC,0);

% Singular values
diag(Sigma);


ndof = 6;
Kshape = U(1:8,1:ndof)*inv(Sigma(1:ndof,1:ndof))*U(:,1:ndof)';

% XSC PIs
Kp = 2.5/2;
Ti = 10;
for i=1:8,
    xsc_pi(i,i)=tf(Kp*[1 1/Ti],[1 0]);
end

sim('PlasmaPlant_XSC');

return


drawVessel;
hold on 
drawPlasma(Shape.signals.values(1,:)',gca,'r');
drawPlasma(Shape.signals.values(end,:)',gca,'k');
grid
