function ret = drawPlasma(plasmaShape,axesHandle,color)
% ret = drawPlasma(shape,[axesHandle],[color])
% Draw a plasma LCF surface  
% Returns 0 if an error occurs and 1 otherwise
%
% shape has the following structure:
%
% shape.gap    - vector
% shape.strike - vector
% shape.xpoint - vector
% 
% Optional parameters:
% - axesHandle (default = gca)
% - color      (default = 'r')

% Gap and strike points data
GapRZ = [3.3294,-1.067,2.9,-0.6;3.872,0,3.2,0;2.057,1.628,2.8,1.2;1.822,0,2.6,0;4.072,0,3.4,0;1.612,0,2.5,0;2.284,1.919,2.284,1;2.483,2.003,2.483,1;2.683,2.022,2.683,1;2.981,1.945,2.981,1;3.252,1.767,3.252,1;3.5881,1.4801,2.9,0.9;3.7601,1.0459,3,0.7;3.6605,-0.6267,2.9,-0.3;2.0481,-0.9298,2.6,-0.6;1.8663,0.8741,2.6,0.7;3.02,-1.336,2.74,-0.7;3.498,-0.848,3,-0.5;3.792,-0.322,3.17,-0.17;3.896,0.23,3.21,0.23;3.889,0.502,3.22,0.39;3.828,0.839,3.23,0.65;3.664,1.268,3.2,0.94;3.243,1.758,2.87,1.06;2.152,1.784,2.72,1.07;1.98,1.394,2.54,1.08;1.892,1.092,2.5,0.9;1.826,0.599,2.58,0.52;1.813,0.26,2.58,0.26;1.867,-0.317,2.5,-0.17;1.955,-0.655,2.51,-0.41;2.18,-1.248,2.74,-0.7];
XPointOffset = [2.678,-1.712];
StrikeNames = {'RSOGB','RSIGB','ZSOGB','ZSIGB'};
StrikeRZ.map = {[0.482 0.278 0.202 -0.063],[-0.559 -0.302 -0.222 0.062],[0.375 0.292 -0.188],[0.375 0.312 -0.188]};
StrikeRZ.rList = {[3.15 2.946 2.87 2.605],[2.109 2.366 2.446 2.73],[2.96 2.885 2.885],[2.36 2.42 2.42]};
StrikeRZ.zList = {[-1.83 -1.744 -1.712 -1.712],[-1.83 -1.74 -1.712 -1.712],[-1.337 -1.42 -1.9],[-1.337 -1.4 -1.9]};
cfg.GeometricalDescriptor = {'ROG','TOG3','RIG','ZSIGB','RSOGB'};
try 
    ret = 0;
    % Check input parameters
    if nargin < 1
        return            
    end
    if nargin < 3
        color = 'r';
        if nargin < 2
            axesHandle = gca;    
        end
    end
    shape.gap    = plasmaShape([1:end-6]);
    shape.strike = plasmaShape(end-5:end-2);
    shape.xpoint = plasmaShape(end-1:end);

    gapR = GapRZ(:,1)+shape.gap.*(GapRZ(:,3)-GapRZ(:,1))./sqrt((GapRZ(:,3)-GapRZ(:,1)).^2+(GapRZ(:,4)-GapRZ(:,2)).^2);
    gapZ = GapRZ(:,2)+shape.gap.*(GapRZ(:,4)-GapRZ(:,2))./sqrt((GapRZ(:,3)-GapRZ(:,1)).^2+(GapRZ(:,4)-GapRZ(:,2)).^2);
    % Check for NaN
    gapR = gapR(find(~isnan(gapR)));
    gapZ = gapZ(find(~isnan(gapZ)));
    if ((shape.xpoint(1) == 0) & (shape.xpoint(2) == 0 ))
        rc = sum(gapR)/length(gapR);
        zc = sum(gapZ)/length(gapZ);
        [gapth, gapro] = cart2pol(gapR-rc,gapZ-zc);
        [gapth,i,j] = unique(gapth);
        gapro = gapro(i);
        [void, i_sort] = sort(gapth);
        newth = [gapth(i_sort(1)):(gapth(i_sort(end))-gapth(i_sort(1)))/100:gapth(i_sort(end))]';
        newro = interp1(gapth(i_sort),gapro(i_sort),newth);
        [newR,newZ] = pol2cart(newth,newro);
        gapR = newR+rc;
        gapZ = newZ+zc;
    else
        gapR =  [XPointOffset(1)+shape.xpoint(1);gapR];
        gapZ =  [XPointOffset(2)+shape.xpoint(2);gapZ];
    end
    % Check for NaN
    gapR = gapR(find(~isnan(gapR)));
    gapZ = gapZ(find(~isnan(gapZ)));
    rc = sum(gapR)/length(gapR);
    zc = sum(gapZ)/length(gapZ);
    [gapth, gapro] = cart2pol(gapR-rc,gapZ-zc);
    [void, i_sort] = sort(gapth);
    plasmaHandle = plot([gapR(i_sort);gapR(i_sort(1))],[gapZ(i_sort);gapZ(i_sort(1))], color,'Parent',axesHandle);
    strikeR = [];
    strikeZ = [];
    xpR     = [];
    xpZ     = [];
    for i = 1:length(shape.strike)
        if ismember(StrikeNames{i},cfg.GeometricalDescriptor)
            if (shape.strike(i) ~= 0)
                strikeR(end+1) = interp1(StrikeRZ.map{i},StrikeRZ.rList{i},shape.strike(i),'linear','extrap');
                strikeZ(end+1) = interp1(StrikeRZ.map{i},StrikeRZ.zList{i},shape.strike(i),'linear','extrap');
            end
        end
    end
    if ((~isnan(shape.xpoint(1))) & (~isnan(shape.xpoint(2))))
%    if ((shape.xpoint(1) ~= 0) & (shape.xpoint(2) ~= 0 ))
       xpR = XPointOffset(1)+shape.xpoint(1);
       xpZ = XPointOffset(2)+shape.xpoint(2);
    end
    r = [strikeR xpR];
    z = [strikeZ xpZ];
    % Check for NaN
    r = r(find(~isnan(r)));
    z = z(find(~isnan(z)));
    if (~isempty(r) & ~isempty(z))
        [r,i_sort] = sort(r);
        z = z(i_sort);
        if (isempty(xpR) & isempty(xpZ))
            plot(r,z,[color '*'],'Parent',axesHandle)
        else
            plot(r,z,color,'Parent',axesHandle)
        end
        axis('equal');    
    end
    ret = 1;
catch
    ret = 0;
end
