%%% Load ITER equilibrium (plasma linearized model)
modelFile  = 'Equil_00019_CL.mat';
load(modelFile);

% Computes indexes to access to the model

% PF indexes in the state and output vectors
PFName = {'ICS1','ICS2U','ICS2L','ICS3U','ICS3L','IPF1','IPF2','IPF3','IPF4','IPF5','IPF6','IVS3'};
PFindex = signalIndexByName(PFName,LinearModel.PoloidalCircuits.Name,LinearModel.PoloidalCircuits.StatePosition);
PFindexOut = signalIndexByName(PFName,LinearModel.PoloidalCircuits.Name,LinearModel.PoloidalCircuits.OutputPosition);
% PF indexes in the input vector (here VS1 is added)
PFNameIn = {'VCS1','VCS2U','VCS2L','VCS3U','VCS3L','VPF1','VPF2','VPF3','VPF4','VPF5','VPF6','VS3','VS1'};
PFindexIn = signalIndexByName(PFNameIn,LinearModel.InputsInfo.Name,[1:length(LinearModel.InputsInfo.Name)]);
% Indexes for the other outputs 
ZCindexout = signalIndexByName('CV-ZC',LinearModel.OutputsInfo.Name,LinearModel.OutputsInfo.OutputPosition);
IpIndexout = LinearModel.PlasmaCurrentInfo.OutputPosition;

% Build model matrices for Simulink simulation 
%
% x' = Ax+Bu+Ew'
% y = Cx+Du+Fw
%
% The INPUT vector holds the voltages applied to the following cicuits:
% CS1, CS2U, CS2L, CS3U, CS3L , PF1-PF6, VS3 (in-vessel coils), VS1
%
% The DISTUBANCES are:
% - betap*Ip
% - li*Ip
%
% The OUTPUT vector holds:
% - the currents in the CS/PF/VS3 coils (typically 12 elements)
% - the plasma current Ip
% - the plasma vertical position z_c
% - the plasma vertical velocity \dot{z}_c

A_contr = -inv(LinearModel.L)*LinearModel.R;
B_contr = inv(LinearModel.L)*LinearModel.S(:,PFindexIn);
E_contr = -inv(LinearModel.L)*LinearModel.LE;
C_contr = LinearModel.C([PFindexOut IpIndexout ZCindexout],:); 
D_contr = LinearModel.D([PFindexOut IpIndexout ZCindexout],PFindexIn);  
F_contr = LinearModel.F; 
F_contr = F_contr([PFindexOut IpIndexout ZCindexout],:);

Czdot = C_contr(end,:)*A_contr;
Dzdot = C_contr(end,:)*B_contr;

C_contr = [C_contr; Czdot];
D_contr = [D_contr; Dzdot];
F_contr = [F_contr; 0 0];

% Change the model state in order to avoid the disturbance derivative in
% input.
% The new state is defined as z = x-Ew

A_w = A_contr;
B_w = B_contr;
C_w = C_contr;
D_w = D_contr;
E_w = A_contr*E_contr;
F_w = C_contr*E_contr+F_contr;


%Disturbances
% VDE
% The VDE is specified in cm 

vde = -10.0;

[VV,DD] = eig(A_w);
idx_unstable = find(diag(DD>1e-3));
Cnew = C_contr(end-1,:)*VV;
z0=1e-2;
xnewi0 = z0/Cnew(idx_unstable);
xxnewi0 = zeros(size(A_w,1),1);
xxnewi0(idx_unstable) = xnewi0;
xi0 = VV*xxnewi0*vde;

% Plasma current at the equilibrium 
Ip0 = LinearModel.XEquil(LinearModel.PlasmaCurrentInfo.StatePosition);

% Example of plasma disturbance 
% H-L transition
tt1 = 0:.001:150e-3;
tt2 = 0:.01:15;
tau1 = 25e-3;
tau2 = 0.36;
expon1 = exp(-tt1/tau1);
expon2 = exp(-tt2/tau2);
betap = [0 0.1 tt1+0.1 tt2+0.1+tt1(end); ...
    0*Ip0 0*Ip0 -(1-expon1)*Ip0*0.05 -(1-exp(-tt1(end)/tau1))*Ip0*0.05+(-1+expon2)*.4*Ip0]';
li = [0 0.1 tt1+0.1 tt2+0.1+tt1(end); ...
    0*Ip0 0*Ip0 (1-expon1)*Ip0*0.05 (1-exp(-tt1(end)/tau1))*Ip0*0.05+(1-expon2)*.1*Ip0]';
 

% 
% ReleON = 100;
% ReleOFF=ReleON/20;
% 
% 
% load('additional_files/KKcontr');
% 
% UB = 400;
% sigma = .58;
% B = 1000;
% Ksat=300/205;

ITERPlant